<?php
namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;

class crm31000AgendaDeTarefasController extends TeknisaCrud
{
    protected $dataSourceName = 'filacontato_agendatarefasprincipal';
    protected $entityManager;
    protected $connection;
    protected $newCode;
    protected $environment;
    protected $parameterBagColumns = array("P_DTINICIO", "P_DTFIM", "P_CDOPERLOGADO");

    public function __construct ($crudService, $parameterBag, $entityManager, $newCode, $emailService, \Teknisa\Libs\Util\Environment $environment, $util)
    {
        $this->entityManager = $entityManager;
        $this->newCode       = $newCode;
        $this->emailService  = $emailService;
        $this->connection    = $entityManager->getConnection();
        $this->environment   = $environment;
        $this->util          = $util;

        parent::__construct($crudService, $parameterBag);
    }
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $request = $this->util->modifyDateFilter($request, 'DTPLANFILACONTA');
        
        parent::find($request, $response);
    }

    public function save(DTO\Request $request, DTO\Response $response) {
        foreach($request->getDataSet()->getRows() as $row) {
            if ($row['__is_new'] && (!isset($row['NRSEQFILACONTA']))) {
               
                $row["NRORG"] = $this->environment->getNrOrgTrab();
                $row['NRSEQFILACONTA'] = $this->newCode->getCodeByTableName("FILACONTATO", $row["NRORG"]);
                $row["CDFILIAL"] = $this->environment->getCdFilial();
                
                $response->addDataSet(new DataSet("DADOS", array("NRSEQFILACONTA" => $row["NRSEQFILACONTA"])));
            }
        }
        
        $this->dataSourceName = 'filacontato_agendatarefasprincipal_full';
        parent::save($request, $response);
        $this->dataSourceName = 'filacontato_agendatarefasprincipal';
    }

    public function concluirTarefa(Row $row, Response $response, $entityManager = null)
    {
        $row = $row->getRow();

        $update = "UPDATE FILACONTATO
                      SET DTREALFILACONTA = SYSDATE
                    WHERE NRSEQFILACONTA  = :NRSEQFILACONTA
                      AND NRORG           = :NRORG";

        $params = array
        (
            "NRSEQFILACONTA"  => $row["NRSEQFILACONTA"],
            "NRORG"           => $row["NRORG"]
        );

        try
        {
            if(!empty($entityManager)){
                $this->entityManager = $entityManager;
            }
            $std = $this->entityManager->getConnection()->prepare($update);
            $std->execute($params);
        }
        catch(\Exception $e)
        {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        };
    }

     public function transferirTarefa(Row $row, Response $response)
    {
        $row = $row->getRow();
        $operador = $row["OPERADOR"];
        $rows = $row["ROW"];

        foreach($rows as $row)
        {
            $update = "UPDATE FILACONTATO
                          SET CDOPERREAL      = :CDOPERREAL
                        WHERE NRSEQFILACONTA  = :NRSEQFILACONTA
                          AND NRORG           = :NRORG
                          AND DTREALFILACONTA IS NULL";

            $params = array
            (
                "CDOPERREAL"     => $operador,
                "NRORG"          => $row["NRORG"],
                "NRSEQFILACONTA" => $row["NRSEQFILACONTA"]
            );
            
            try
            {
                $std = $this->entityManager->getConnection()->prepare($update);
                $std->execute($params);
            }
            catch(\Exception $e)
            {
                $response->setError(new Error($e->getMessage(), $e->getCode()));
            };
        }
    }

    public function getOperadorLogado(Row $row, Response $response) {
        $select = "SELECT *
                     FROM OPERADOR
                    WHERE CDOPERADOR = :CDOPERADOR
                      AND NRORG      = :NRORG";

        $params = array
        (
            "CDOPERADOR" => $this->environment->getCdOperador(),
            "NRORG"      => $this->environment->getNrOrgTrab()
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($select);
            $std->execute($params);
            $result = $std->fetchAll();
            $response->addDataSet(new DataSet("DADOS", $result));
        }
        catch(\Exception $e)
        {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        };
    }
    
    public function deactivateTask(Row $row, Response $response) {
        $row = $row->getRow();

    
        $update = "UPDATE FILACONTATO
                      SET IDATIVO = 'N'
                    WHERE NRSEQFILACONTA  = :NRSEQFILACONTA
                      AND NRORG           = :NRORG";

        $params = array
        (
            "NRORG"          => $row["NRORG"],
            "NRSEQFILACONTA" => $row["NRSEQFILACONTA"]
        );

        try
        {
            $std = $this->entityManager->getConnection()->prepare($update);
            $std->execute($params);
        }
        catch(\Exception $e)
        {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        };
    }
    
    public function incluiContato(Row $row, Response $response) {
        try {
            $row = $row->getRow();
            
            $nrseqcontato = $this->newCode->getCodeByTableName("NRSEQCONTATO", $row["NRORG"]);
            $nrcontato = (int)$nrseqcontato;
            
            $update = "UPDATE FILACONTATO
                          SET NRCONTATO = :NRCONTATO,
                              NRSEQCONTATO = :NRSEQCONTATO
                        WHERE NRSEQFILACONTA  = :NRSEQFILACONTA
                          AND NRORG           = :NRORG";
                
            $params = array (
                "NRORG"          => $row["NRORG"],
                "NRCONTATO"      => $nrcontato,
                "NRSEQCONTATO"   => $nrseqcontato,
                "NRSEQFILACONTA" => $row["NRSEQFILACONTA"]
            );
            
            $std = $this->entityManager->getConnection()->prepare($update);
            $std->execute($params);
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        };
    }
    
    public function findEvol(DTO\Request $request, DTO\Response $response){
        $this->dataSourceName = 'evolcont_parcnegocio';
        $this->parameterBagColumns = array('P_NRPARCNEGOCIO', 'P_NRORG');
        parent::find($request, $response);
    }
    
    public function enviaEmailTarefa($row){
        //Trata os dados
        $row["NUMEROTICKETRELACIONADO"] = null;
        $row["DSTIPO"] = '.';
        
        if($row["TIPO"] == "PARCEIRO"){
            $row["DSTIPO"] = ' relacionada ao Parceiro' ;
            $row["NUMEROTICKETRELACIONADO"] = $row["DESCRICAO"];
            
        }else if($row["TIPO"] == "OPORTUNIDADE"){
            $row["DSTIPO"] = ' relacionada à Oportunidade';
            $row["NUMEROTICKETRELACIONADO"] = $row["DESCRICAO"];
            
        }else if($row["TIPO"] == "CHAMADO"){
            $row["DSTIPO"] = ' relacionada ao Ticket' ;
            $row["NUMEROTICKETRELACIONADO"] = ' #'.$row["NRSEQCONTATO"].' - '.$row["DESCRICAO"] ;
        }
        
        if(empty($row["NMOPERREAL"])) $row["NMOPERREAL"]  = 'Sem Operador';
        if(empty($row["OPERADORDOLOGADO"])) $row["OPERADORDOLOGADO"]  = 'Sem Operador';
        if(empty($row["DSTIPO"])) $row["DSTIPO"]  = '';
        if(empty($row["DESCRICAO"])) $row["DESCRICAO"]  = 'Sem Relacionamento';
        if(empty($row["NRSEQCONTATO"])) $row["NRSEQCONTATO"]  = 'Sem Relacionamento';
        if(empty($row["DSFILACONTATO"])) $row["DSFILACONTATO"]  = 'Sem Assunto ';
        if(empty($row["NMPARCNEGOCIO"])) $row["NMPARCNEGOCIO"]  = 'Sem Parceiro';
        if(empty($row["DTPLANFILACONTA"])) $row["DTPLANFILACONTA"]  = 'Sem Data da Tarefa';
        if(empty($row["DTVENCFILACONTA"]) && empty($row["DTREALFILACONTA"])) $row["DTVENCFILACONTA"]  = 'Sem Data de Vencimento';
        if(empty($row["DSCLASSIFICATAREFA"])) $row["DSCLASSIFICATAREFA"]  = 'Sem Classificação';
        if(empty($row["DSDETEFILACONTA"])) $row["DSDETEFILACONTA"]  = 'Sem Descrição';
        
        //Dados de envio do email
        $parametrosEmail = array(
            'to' => array( 
                'email' => $row["DSEMAILOPER"],
                'name'  => $row["NMOPERREAL"],
            ),
            'subject' => 'CRM - Nova Tarefa',
            'from' => 'Equipe CRM'
        );
        //Monta o template
        $template = '<table border="0" width="100%" cellpadding="0" cellspacing="0" bgcolor="eeeeee" style="background-color: #eeeeee;"> <tbody> <tr> <td> <table border="0" align="center" width="590" cellpadding="0" cellspacing="0" bgcolor="0274BA" class="container590" style="background-color: #0274ba; text-align: center;"> <tbody> <tr> <td> <table border="0" align="center" width="540" cellpadding="0" cellspacing="0" class="container580"> <tbody> <tr> <td align="center" valign="middle"> <table border="0" align="middle" cellpadding="0" cellspacing="0" style="border-collapse:collapse; mso-table-lspace:0pt; mso-table-rspace:0pt;" class=""> <tbody> <tr> <td align="center" valign="middle"> <p style="color: #ffffff; font-size: 25px; padding:20px; font-family: " Questrial ", Helvetica, sans-serif; line-height: 25px; padding-top:45px;">NOTIFICAÇÃO DE NOVA TAREFA</p> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table> <table border="0" width="100%" cellpadding="0" cellspacing="0" bgcolor="eeeeee"> <tbody> <tr> <td align="center"> <table border="0" align="center" width="590" cellpadding="0" cellspacing="0" bgcolor="ffffff" class="container590 bg_color"> <tbody> <tr> <td> <table border="0" align="center" width="540" cellpadding="0" cellspacing="0" class="container580"> <tbody> <tr> <td align="left" style="color: #39434b; font-size: 20px; font-family: " Montserrat ", Helvetica, sans-serif; font-weight: 400; padding-bottom:15px; padding-top:20px; line-height: 35px;" class="title_color"> <div style="padding:20px; line-height: 22px"> Prezado(a) [OPERADORDOEMAIL]</div> </td> </tr> <tr> <td align="left" class="title_color" style="color: #848999; font-size: 14px; font-family: " Questrial ", sans-serif; mso-line-height-rule: exactly; line-height: 24px; padding-bottom:15px;"> <div style="line-height: 24px;"> <p>O [OPERADOR] criou uma nova tarefa para você [RELACIONAMENTO] &nbsp <b> [NUMEROTICKETRELACIONADO]</b><br> <br> Segue os dados da Tarefa: <ul> <li> <p><b>Assunto:</b> [ASSUNTO]</p> </li> <li> <p><b>Parceiro:</b> [PARCEIRO]</p> </li> <li> <p><b>Data da Tarefa:</b> [DATACOMPROMISSO]</p> </li> <li> <p><b>Data de Vencimento:</b> [DATAVENCIMENTO]</p> </li> <li> <p><b>Classificação:</b> [CLASSIFICACAO]</p> </li> <li> <p><b>Descrição:</b> [DESCRICAO]</p> </li> </ul> </p> <br> </div> </td> </tr> <tr> <td height="10" style="font-size: 10px; line-height: 10px;">&nbsp;</td> </tr> </tbody> </table> </td> </tr> </tbody> </table> </td> </tr> </tbody> </table>';

        $template = strtr($template, array('[OPERADORDOEMAIL]'              => $row["NMOPERREAL"] , 
                                           '[OPERADOR]'                     => $row["OPERADORDOLOGADO"],
                                           '[RELACIONAMENTO]'               => $row["DSTIPO"],
                                           '[NUMEROTICKETRELACIONADO]'      => $row["NUMEROTICKETRELACIONADO"],
                                           '[ASSUNTO]'                      => $row["DSFILACONTATO"],
                                           '[PARCEIRO]'                     => $row["NMPARCNEGOCIO"],
                                           '[DATACOMPROMISSO]'              => $row["DTPLANFILACONTA"],
                                           '[DATAVENCIMENTO]'               => $row["DTVENCFILACONTA"],
                                           '[CLASSIFICACAO]'                => $row["DSCLASSIFICATAREFA"],
                                           '[DESCRICAO]'                    => $row["DSDETEFILACONTA"]));
        //Rotina de enviar email                                    
        $this->emailService->enviarEmailCompromisso('EMAILGENERICO', $parametrosEmail['to']['email'], $parametrosEmail['subject'], array('template' => $template), $parametrosEmail['from'], $parametrosEmail['to']['name'], null, null, null);
        
    }
    
    public function callEnviaEmailTarefa(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        self::enviaEmailTarefa($row); 
    }
}