<?php
namespace Teknisa\CRM\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Util\NovoCodigo;
use Teknisa\CRM\Util\Util;

class InterlocutoresPendentesFactory
{
    protected $entityManager;
    protected $environment;
    
    public function __construct(EntityManager $entityManager, $environment) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
    }
    
    public function setParcOnInterloc($row) {
       $interloc = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\CrmInterlocutor')->findOneBy(
            array(
                'nrorg' => $this->environment->getNrOrgTrab(),
                'nrseqinterlocutor'=> $row['NRSEQINTERLOCUTOR']
            )
        );
        
        if(is_object($interloc)){
            
            $interloc->setNrparcnegocio($row['NRPARCNEGOCIOCLIENTE']);
            
            $this->entityManager->persist($interloc);
            $this->entityManager->flush();
            
            return $interloc->getNrseqinterlocutor();
        }else{
            return 'Interlocutor não encontrado';
        }
    }
    
    public function setClientOnOper($row) {
       $oper = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Operador')->findOneBy(
            array(
                'nrorg' => $this->environment->getNrOrgTrab(),
                'nrparcnegocio'=> $row['NRPARCNEGOCIOINTERLOCUTOR']
            )
        );
        
        if(is_object($oper)){
            
            $oper->setCdcliente($row['CDCLIENTE']);
            
            $this->entityManager->persist($oper);
            $this->entityManager->flush();
            
            return $oper->getCdoperador();
        }else{
            return 'Operador não encontrado';
        }
    }
    
    public function setClientOnTickets($row) {
       $tickets = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\Contato')->findBy(
            array(
                'nrorg' => $this->environment->getNrOrgTrab(),
                'nrparcinterlocutor'=> $row['NRPARCNEGOCIOINTERLOCUTOR']
            )
        );
        if(is_array($tickets)){
            
            $ticketsUpdated = array();
            foreach($tickets as $ticket){
                $ticket->setNrparcnegocio($row['NRPARCNEGOCIOCLIENTE']);
                $ticketsUpdated[] = $ticket->getNrseqcontato();
                
                $this->entityManager->persist($ticket);
                $this->entityManager->flush();
            }
            
            return $ticketsUpdated;
        }else{
            return array();
        }
    }
    
    public function setDtultatuInterloc($nrseqinterlocutor) {
       $interloc = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\CrmInterlocutor')->findOneBy(
            array(
                'nrorg' => $this->environment->getNrOrgTrab(),
                'nrseqinterlocutor'=> $nrseqinterlocutor
            )
        );
        
        if(is_object($interloc)){
            
            $interloc->setDtultatu(new \DateTime());
            
            $this->entityManager->persist($interloc);
            $this->entityManager->flush();
            
            return $interloc->getNrseqinterlocutor();
        }else{
            return 'Interlocutor não encontrado';
        }
    }
    
    public function deleteParcnegocio($row) {
       $interloc = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\CrmInterlocutor')->findOneBy(
            array(
                'nrorg' => $this->environment->getNrOrgTrab(),
                'nrseqinterlocutor'=> $row['NRSEQINTERLOCUTOR']
            )
        );
        if(is_object($interloc)){
            $this->entityManager->remove($interloc);
            
            $comunicaparc = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Comunicaparc')->findOneBy(
                array(
                    'nrorg' => $this->environment->getNrOrgTrab(),
                    'nrparcnegocio'=> $row['NRPARCNEGOCIO']
                )
            );
            if(is_object($comunicaparc)){
                $this->entityManager->remove($comunicaparc);
            }
            
            $parcnegocio = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Parcnegocio')->findOneBy(
                array(
                    'nrorg' => $this->environment->getNrOrgTrab(),
                    'nrparcnegocio'=> $row['NRPARCNEGOCIO']
                )
            );
            if(is_object($parcnegocio)){
                $parcnegocio->setIdativo('N');
                $this->entityManager->persist($parcnegocio);
            }
            
            $this->entityManager->flush();
        }else{
            throw new \Exception('Interlocutor não encontrado');
        }
    }
    
    public function deleteOper($row) {
       $oper = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Operador')->findOneBy(
            array(
                'nrorg' => $this->environment->getNrOrgTrab(),
                'nrparcnegocio'=> $row['NRPARCNEGOCIO']
            )
        );
        if(is_object($oper)){
            $this->entityManager->remove($oper);
            $this->entityManager->flush();
        }else{
            throw new \Exception('Operador não encontrado');
        }
    }
    
    public function cancelTickets($row) {
       $tickets = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\Contato')->findBy(
            array(
                'nrorg' => $this->environment->getNrOrgTrab(),
                'nrparcinterlocutor'=> $row['NRPARCNEGOCIO']
            )
        );
        if(is_array($tickets)){
            
            foreach($tickets as $ticket){
                $ticket->setIdcancelado('S');
                
                $this->entityManager->persist($ticket);
                $this->entityManager->flush();
            }
            
        }else{
            return array();
        }
    }
    
    
}