function crm00050002_Reserva_de_Prospect_Controller(crm00050002_Reserva_de_Prospect_Service, ScreenService, restEngine, CRM_Utilities) {
    
   /**
     * Função para formatar a inscrição e setar
     * o tipo de inscrição, quando o modo
     * view for chamado.
     * 
     * @param {object(widget)} widget widget ativa
     * entrando no mode view.
    */
    this.formatProspectInscriptionInView = function(widget){
            
            var currentRow = widget.currentRow;
            var inscription = this.removeInscriptionMask(currentRow.NRINSJURPROS);
            var inscriptionType;
            
            switch (inscription.length) {
                case 5:
                    
                    inscriptionType = "Código";
                break;
                
                case 11:
                    
                    inscription = inscription.replace(/(\d{3})(\d{3})(\d{3})(\d{2})/, "$1.$2.$3-$4");
                    inscriptionType = "CPF";
                break;
                
                case 14:
                    
                    inscription = inscription.replace(/^(\d{2})(\d{3})(\d{3})(\d{4})(\d{2})/, "$1.$2.$3/$4-$5");
                    inscriptionType = "CNPJ";
                break;
                
                default:
                
                    inscriptionType = "Livre";
                break;
            }
        
        currentRow.NRINSJURPROS = inscription;
        currentRow.CDTIPOINSC = inscriptionType;
        
    };
    
    /**
     * Função para remover a máscara de uma 
     * inscrição.
     * 
     * @param {string} inscription isncrição com máscara.
     * 
     * @return {string} inscriptionWithoutMask inscrição
     * sem máscara.
    */
    this.removeInscriptionMask = function(inscription){
        
        var inscriptionWithoutMask = inscription.replace(/[^0-9]/g, "");
        
        return inscriptionWithoutMask;
        
    };
    
    /**
     * Função para reservar um prospect a revenda
     * ligada ao operador em caso.
     * 
     * @param {object(widget)} widget widget ativa
     * no ambiente de reserva de prospect.
    */
    this.reserveProspectToOperator = function(widget){
        
        var currentRow = widget.currentRow;
            
        if(currentRow.ESTADORESERVA === "B"){
            ScreenService.showMessage('Prospect já vinculado a uma revenda.');
        }else{
            this.insertResaleProspect(widget);
        }
        
    };
    
    /**
     * Função para relacionar o prospect
     * selecionado a revenda do operador
     * logado.
     * 
     * @param {object(widget)} widget widget ativa
     * no ambiente de reserva de prospect.
    */
    this.insertResaleProspect = function(widget){
      
        var currentRow = widget.currentRow;
        
        this.setOperatorResaleNumberInCurrentRow(widget).then(function(){
                
            ScreenService.confirmMessage("Deseja vincular o prospect <br/>" + "'" + currentRow.NMRAZSOCPROS + "'" + "<br/> à Revenda <br/>" + "'" + currentRow.NMRAZSOCREVENDA + "'?", "question", function(){
             
                crm00050002_Reserva_de_Prospect_Service.callForInsertResaleProspect(currentRow).then(function(){
                    
                    currentRow.ESTADORESERVA = "B";
                    ScreenService.showMessage('Prospect vinculado com sucesso.');
                    
                }.bind(this));
                
            }.bind(this));    
          
        }.bind(this));
        
    };
    
    /**
     * Função para setar o número da revenda ligado
     * ao operador logado, na currentRow.
     * 
     * @param {object(widget)} widget widget ativa
     * no ambiente de reserva de prospect.
     * 
     * @return {object} promise promise retornado
     * pela requisição.
    */
    this.setOperatorResaleNumberInCurrentRow = function(widget){
        
        var currentRow = widget.currentRow;
        
        return this.getOperatorResaleNumber(widget).then(function(response){
            
            currentRow.NRREVENDA = response.dataset.DADOS[0].NRREVENDA;
            currentRow.NMRAZSOCREVENDA = response.dataset.DADOS[0].NMRAZSOCREVENDA;
            
        });
        
    };
    
    /**
     * Função para buscar o número da revenda
     * ligado ao operador logado.
     * 
     * @param {object(widget)} widget widget ativa
     * no ambiente de reserva de prospect.
     * 
     * @return {object} promise promise retornado
     * pela requisição.
    */
    this.getOperatorResaleNumber = function(widget){
        
        var currentRow = widget.currentRow;
        
        this.setOperatorLoggedCodeInCurrentRow(widget);
        
        return crm00050002_Reserva_de_Prospect_Service.callForSelectOperatorResaleNumber(currentRow);
        
    };
    
    /**
     * Função para setar o código do operadot logado
     * na currentRow do ambiente de reserva.
     * 
     * @param {object(widget)} widget widget ativa
     * no ambiente de reserva de prospect.
    */
    this.setOperatorLoggedCodeInCurrentRow = function(widget){
    
        var currentRow = widget.currentRow;
        var loggedOperatorInfos = CRM_Utilities.getLoggedOperatorInfos();
        
        currentRow.CDOPERADOR = loggedOperatorInfos.CDOPERADOR;
        
    };
    
    /**
     * Função para enviar email.
     * 
     * @param {object(widget)} widget widget ativa onde
     * está localizado as informações do envio do E-Mail.
    */
    this.sendEmailToResaleResponsibleOperator = function(widget){
        
        var currentRow = widget.currentRow;
        
        crm00050002_Reserva_de_Prospect_Service.callForSendEmail(currentRow);
        
    };

}

Configuration(function (ContextRegister) {
    ContextRegister.register("crm00050002_Reserva_de_Prospect_Controller", crm00050002_Reserva_de_Prospect_Controller);
});
